import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/material/delGroup")
def content_material_delgroup(groupId=None, headers=None, **kwargs):
    """
    素材-删除分组-Y
    up_time=1675651277

    params: groupId : number : 素材分组主键
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/material/delGroup"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "groupId": groupId,  # 素材分组主键
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/material/delMaterial")
def content_material_delmaterial( headers=None, **kwargs):
    """
    素材-批量删除
    up_time=1675133826

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/material/delMaterial"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/material/updateGroup")
def content_material_updategroup(groupName=None, groupId=None, headers=None, **kwargs):
    """
    素材-更新素材分组-Y
    up_time=1675651159

    params: groupName : string : 分组名称
    params: groupId : number : 分组主键
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/material/updateGroup"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "groupName": groupName,  # 分组名称
        "groupId": groupId,  # 分组主键
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/material/getMaterialList")
def content_material_getmateriallist(size=None, groupId=None, current=None, headers=None, **kwargs):
    """
    素材-根据素材组获取素材列表
    up_time=1675133826

    params: groupId :  : 分组主键
    params: size :  : 每页数据数
    params: current :  : 当前页
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 
              size : number : 
              current : number : 
              orders : array : 
              optimizeCountSql : boolean : 
              searchCount : boolean : 
              countId : null : 
              maxLimit : null : 
              pages : number : 
    """
    _method = "GET"
    _url = "/content/material/getMaterialList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "groupId": groupId,  # 分组主键
        "size": size,  # 每页数据数
        "current": current,  # 当前页
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/material/addGroup")
def content_material_addgroup(groupName=None, headers=None, **kwargs):
    """
    素材-添加素材分组-Y
    up_time=1675651559

    params: groupName : string : 分组名称
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/material/addGroup"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "groupName": groupName,  # 分组名称
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/material/addMaterial")
def content_material_addmaterial(file=None, groupId=None, headers=None, **kwargs):
    """
    素材-素材上传
    up_time=1675133827

    params: file : file : 上传文件
    params: groupId : text : 所属分组主键
    params: headers : 请求头
    ====================返回======================
    params: url : string : 素材路径
    """
    _method = "POST"
    _url = "/content/material/addMaterial"

    _headers = {
        "Content-Type": "multipart/form-data",
    }
    _headers.update({"headers": headers})

    _data = {
        "file": file,  # 上传文件
        "groupId": groupId,  # 所属分组主键
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/material/getGroupList")
def content_material_getgrouplist(groupName=None, headers=None, **kwargs):
    """
    素材-素材组列表-Y
    up_time=1675651014

    params: groupName :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 数据总数
              size : number : 每页数据数
              current : number : 当前页数
              orders : array : 
              optimizeCountSql : boolean : 
              searchCount : boolean : 
              countId : null : 
              maxLimit : null : 
              pages : number : 
    """
    _method = "GET"
    _url = "/content/material/getGroupList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "groupName": groupName,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.order.mainorder.asserts_order_mainorder_scrm2app import AssertsOrderMainorderScrm2App
from service.app_a.apis.order.mainorder import apis_order_mainorder_scrm2app


class FunsOrderMainorderScrm2App(AssertsOrderMainorderScrm2App):
    @allure.step(title="订单管理-订单退款-Y")
    def order_mainorder_scrm2app_refundauditnotice(self, status="$None$", orderSubId="$None$", orderMainId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/order/mainOrder/scrm2app/refundAuditNotice
                params: orderMainId : string :
                params: orderSubId : string :
                params: status : integer :
                params: headers : 请求头
        """
        status = self.get_value_choice(status, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        orderSubId = self.get_value_choice(orderSubId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        orderMainId = self.get_value_choice(orderMainId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_mainorder_scrm2app.order_mainorder_scrm2app_refundauditnotice(**_kwargs)

        self.assert_order_mainorder_scrm2app_refundauditnotice(_assert, **_kwargs)
        self.set_value(_kwargs)





from service.app_a.apis import apis_app_a
from service.app_a.asserts.asserts_app_a import AssertsAppA
import allure
from service.app_a.funs.funs_order import FunsOrder
from service.app_a.funs.funs_open import FunsOpen
from service.app_a.funs.funs_content import FunsContent
from service.app_a.funs.funs_admin import FunsAdmin
from service.app_a.funs.funs_common import FunsCommon
from service.app_a.funs.funs_goods import FunsGoods
from service.app_a.funs.funs_activitymanager import FunsActivitymanager
from service.app_a.funs.funs_radarpoints import FunsRadarpoints
from service.app_a.funs.funs_pay import FunsPay
from service.app_a.funs.funs_testdrive import FunsTestdrive
from service.app_a.funs.funs_manageapi import FunsManageapi
from service.app_a.funs.funs_essay import FunsEssay
from service.app_a.funs.funs_area import FunsArea


class FunsAppA(FunsOrder, FunsOpen, FunsContent, FunsAdmin, FunsCommon, FunsGoods, FunsActivitymanager, FunsRadarpoints, FunsPay, FunsTestdrive, FunsManageapi, FunsEssay, AssertsAppA, FunsArea):
    @allure.step(title="网点列表-获取经销商")
    def page(self, shopBusinessType="$None$", city="$None$", size=10, cityNameSort="$None$", provinceNameSort="$None$", province="$None$", districtNameSort="$None$", dealerCode="$None$", dealerAddress="$None$", dealerName="$None$", district="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/page
                params: current :  :
                params: size :  :
                params: province :  :
                params: city :  :
                params: district :  :
                params: dealerCode :  :
                params: dealerName :  :
                params: dealerAddress :  :
                params: shopBusinessType :  :
                params: cityNameSort :  :
                params: districtNameSort :  :
                params: provinceNameSort :  :
                params: headers : 请求头
        """
        shopBusinessType = self.get_list_choice(shopBusinessType, list_or_dict=None, key="shopBusinessType")
        city = self.get_list_choice(city, list_or_dict=None, key="city")
        cityNameSort = self.get_list_choice(cityNameSort, list_or_dict=None, key="cityNameSort")
        provinceNameSort = self.get_list_choice(provinceNameSort, list_or_dict=None, key="provinceNameSort")
        province = self.get_list_choice(province, list_or_dict=None, key="province")
        districtNameSort = self.get_list_choice(districtNameSort, list_or_dict=None, key="districtNameSort")
        dealerCode = self.get_list_choice(dealerCode, list_or_dict=None, key="dealerCode")
        dealerAddress = self.get_list_choice(dealerAddress, list_or_dict=None, key="dealerAddress")
        dealerName = self.get_list_choice(dealerName, list_or_dict=None, key="dealerName")
        district = self.get_list_choice(district, list_or_dict=None, key="district")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_app_a.page(**_kwargs)

        self.assert_page(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/radarpoints/summaryStatistics/pageList")
def radarpoints_summarystatistics_pagelist(flowTimeEnd=None, size=None, current=None, flowTimeBefore=None, headers=None, **kwargs):
    """
    积分汇总统计-分页查询积分
    up_time=1676623470

    params: current :  : 
    params: size :  : 
    params: flowTimeBefore :  : 流水开始时间
    params: flowTimeEnd :  : 流水结束时间
    params: headers : 请求头
    ====================返回======================
    params: code : string : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              size : string : 
              current : string : 
              total : string : 
    """
    _method = "GET"
    _url = "/radarpoints/summaryStatistics/pageList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "current": current,
        "size": size,
        "flowTimeBefore": flowTimeBefore,  # 流水开始时间
        "flowTimeEnd": flowTimeEnd,  # 流水结束时间
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/radarpoints/summaryStatistics/export")
def radarpoints_summarystatistics_export(flowTimebefore=None, flowTimeEnd=None, size=None, current=None, headers=None, **kwargs):
    """
    积分汇总统计 - 导出
    up_time=1676625526

    params: current :  : 
    params: size :  : 
    params: flowTimeEnd :  : 
    params: flowTimebefore :  : 
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/radarpoints/summaryStatistics/export"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "current": current,
        "size": size,
        "flowTimeEnd": flowTimeEnd,
        "flowTimebefore": flowTimebefore,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.content.asserts_content_noticemanager import AssertsContentNoticemanager
from service.app_a.apis.content import apis_content_noticemanager


class FunsContentNoticemanager(AssertsContentNoticemanager):
    @allure.step(title="系统通知列表查询接口-Y")
    def content_noticemanager_page(self, _assert=True,  **kwargs):
        """
            url=/content/noticeManager/page
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_noticemanager.content_noticemanager_page(**_kwargs)

        self.assert_content_noticemanager_page(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="获取系统通知详情")
    def content_noticemanager_getnoticeparamslist_(self, messageId="$None$", templateType="$None$", _assert=True,  **kwargs):
        """
            url=/content/noticeManager/getNoticeParamsList/{messageId}
                params: messageId :  :
                params: templateType :  : 模板编码
                params: headers : 请求头
        """
        messageId = self.get_list_choice(messageId, list_or_dict=None, key="messageId")
        templateType = self.get_list_choice(templateType, list_or_dict=None, key="templateType")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_noticemanager.content_noticemanager_getnoticeparamslist_(**_kwargs)

        self.assert_content_noticemanager_getnoticeparamslist_(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="系统通知变量编辑-Y")
    def content_noticemanager_noticeparamsupdate(self, templateName="$None$", templateContent="$None$", templateType="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/noticeManager/noticeParamsUpdate
                params: templateType : string : 模板类型
                params: templateName : string : 模板名称（标题）
                params: templateContent : string : 模板内容
                params: headers : 请求头
        """
        templateName = self.get_value_choice(templateName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        templateContent = self.get_value_choice(templateContent, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        templateType = self.get_value_choice(templateType, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_noticemanager.content_noticemanager_noticeparamsupdate(**_kwargs)

        self.assert_content_noticemanager_noticeparamsupdate(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_topic4c import SqlsContentTopic4C


class AssertsContentTopic4C(SqlsContentTopic4C):
    @allure.step(title="接口返回结果校验")
    def assert_content_topic4c_del(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_topic4c_del(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["topicId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_topic4c_getcontentlist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_topic4c_getcontentlist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["topicId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_topic4c_list(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_topic4c_list(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["keyWord", "topicId", "endTime", "createBy", "startTime"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_topic4c_insert(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_topic4c_insert(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["topicTitle", "topicId", "author"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_topic4c_top(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_topic4c_top(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["topicId", "type"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a.asserts.content.asserts_content_essay import AssertsContentEssay
from service.app_a.apis.content import apis_content_essay


class FunsContentEssay(AssertsContentEssay):
    @allure.step(title="专题-后台APP专题文章删除-Y")
    def content_essay_delete_(self, essayId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/essay/delete/{essayId}
                params: essayId :  : 文章id
                params: headers : 请求头
        """
        essayId = self.get_value_choice(essayId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_essay.content_essay_delete_(**_kwargs)

        self.assert_content_essay_delete_(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="专题-后台App文章关键词搜索-Y")
    def content_essay_searchbykey(self, current=1, size=10, Key="$None$", _assert=True,  **kwargs):
        """
            url=/content/essay/searchByKey
                params: Key :  : 关键词
                params: size :  : 条数
                params: current :  : 当前页
                params: headers : 请求头
        """
        Key = self.get_list_choice(Key, list_or_dict=None, key="Key")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_essay.content_essay_searchbykey(**_kwargs)

        self.assert_content_essay_searchbykey(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="后台管理-内容审核列表1030-Y")
    def content_essay_checklist(self, subjectId="$None$", size=10, keyWord="$None$", CreateTimeSortType="$None$", endTime="$None$", recommend="$None$", PublishTimeSortType="$None$", status="$None$", author="$None$", essayId="$None$", StatusSortType="$None$", startTime="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/content/essay/checkList
                params: essayId :  : 文章主键
                params: keyWord :  : 文章搜索关键字
                params: author :  : 作者
                params: startTime :  : 搜索开始时间
                params: endTime :  : 搜索结束时间
                params: subjectId :  : 专题主键
                params: status :  : 文章状态1：待上架2：已上架3：已下架4：已删除 5 待审核 6 审核不通过 7草稿
                params: size :  : 每页条数
                params: current :  : 当前页数
                params: recommend :  : 是否推荐 1：推荐页0：非推荐页
                params: PublishTimeSortType :  : 发布时间排序方式 默认倒序，正序  ASC 倒序 DESC
                params: CreateTimeSortType :  : 创建时间排序方式 默认倒序，  正序  ASC 倒序 DESC
                params: StatusSortType :  : 状态排序方式 默认倒序，  正序  ASC 倒序 DESC
                params: headers : 请求头
        """
        subjectId = self.get_list_choice(subjectId, list_or_dict=None, key="subjectId")
        keyWord = self.get_list_choice(keyWord, list_or_dict=None, key="keyWord")
        CreateTimeSortType = self.get_list_choice(CreateTimeSortType, list_or_dict=None, key="CreateTimeSortType")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        recommend = self.get_list_choice(recommend, list_or_dict=None, key="recommend")
        PublishTimeSortType = self.get_list_choice(PublishTimeSortType, list_or_dict=None, key="PublishTimeSortType")
        status = self.get_list_choice(status, list_or_dict=None, key="status")
        author = self.get_list_choice(author, list_or_dict=None, key="author")
        essayId = self.get_list_choice(essayId, list_or_dict=None, key="essayId")
        StatusSortType = self.get_list_choice(StatusSortType, list_or_dict=None, key="StatusSortType")
        startTime = self.get_list_choice(startTime, list_or_dict=None, key="startTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_essay.content_essay_checklist(**_kwargs)

        self.assert_content_essay_checklist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="后台管理-内容管理列表1030-Y")
    def content_essay_list(self, subjectId="$None$", size=10, keyWord="$None$", CreateTimeSortType="$None$", endTime="$None$", recommend="$None$", PublishTimeSortType="$None$", status="$None$", author="$None$", essayId="$None$", StatusSortType="$None$", startTime="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/content/essay/list
                params: essayId :  : 文章主键
                params: keyWord :  : 文章搜索关键字
                params: author :  : 作者
                params: startTime :  : 搜索开始时间
                params: endTime :  : 搜索结束时间
                params: subjectId :  : 专题主键
                params: status :  : 文章状态1：待上架2：已上架3：已下架4：已删除 5 待审核 6 审核不通过 7草稿
                params: size :  : 每页条数
                params: current :  : 当前页数
                params: recommend :  : 是否推荐 1：推荐页0：非推荐页
                params: PublishTimeSortType :  : 发布时间排序方式 默认倒序，正序  ASC 倒序 DESC
                params: CreateTimeSortType :  : 创建时间排序方式 默认倒序，  正序  ASC 倒序 DESC
                params: StatusSortType :  : 状态排序方式 默认倒序，  正序  ASC 倒序 DESC
                params: headers : 请求头
        """
        subjectId = self.get_list_choice(subjectId, list_or_dict=None, key="subjectId")
        keyWord = self.get_list_choice(keyWord, list_or_dict=None, key="keyWord")
        CreateTimeSortType = self.get_list_choice(CreateTimeSortType, list_or_dict=None, key="CreateTimeSortType")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        recommend = self.get_list_choice(recommend, list_or_dict=None, key="recommend")
        PublishTimeSortType = self.get_list_choice(PublishTimeSortType, list_or_dict=None, key="PublishTimeSortType")
        status = self.get_list_choice(status, list_or_dict=None, key="status")
        author = self.get_list_choice(author, list_or_dict=None, key="author")
        essayId = self.get_list_choice(essayId, list_or_dict=None, key="essayId")
        StatusSortType = self.get_list_choice(StatusSortType, list_or_dict=None, key="StatusSortType")
        startTime = self.get_list_choice(startTime, list_or_dict=None, key="startTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_essay.content_essay_list(**_kwargs)

        self.assert_content_essay_list(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="后台管理-新建&修改内容1030-Y")
    def content_essay_add(self, subjectId="$None$", videoUrl="$None$", essayType="$None$", recommend="$None$", essPicUrl="$None$", publishType="$None$", author="$None$", essayId="$None$", title="$None$", content="$None$", status="$None$", publishTime="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/essay/add
                params: essayId : string : 文章主键
                params: title : string : 标题
                params: author : string : 作者
                params: publishType : number : 发布类型1：立即发布2：定时发布
                params: publishTime : string : 发布时间
                params: content : string : 富文本内容
                params: status : string : 状态 新增状态为待审核 1：待上架2：已上架 3 ：已下架4：已删除 5待审核 6 审核不通过 7 草稿
                params: essayType : string : 文章类型1：图文2：视频
                params: subjectId : array : 专题主键
                type : string : None
                params: recommend : number : 是否推荐 1：推荐页0：非推荐页
                params: essPicUrl : string : 封面
                params: videoUrl : string : 视频路径
                params: headers : 请求头
        """
        subjectId = self.get_value_choice(subjectId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        videoUrl = self.get_value_choice(videoUrl, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        essayType = self.get_value_choice(essayType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        recommend = self.get_value_choice(recommend, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        essPicUrl = self.get_value_choice(essPicUrl, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        publishType = self.get_value_choice(publishType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        author = self.get_value_choice(author, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        essayId = self.get_value_choice(essayId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        title = self.get_value_choice(title, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        content = self.get_value_choice(content, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        status = self.get_value_choice(status, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        publishTime = self.get_value_choice(publishTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_essay.content_essay_add(**_kwargs)

        self.assert_content_essay_add(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="文章-生成文章主键-Y")
    def content_essay_createid(self, _assert=True,  **kwargs):
        """
            url=/content/essay/createId
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_essay.content_essay_createid(**_kwargs)

        self.assert_content_essay_createid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="后台管理-内容详情1030-Y")
    def content_essay_getbyid(self, essayId="$None$", _assert=True,  **kwargs):
        """
            url=/content/essay/getById
                params: essayId :  : 文章主键
                params: headers : 请求头
        """
        essayId = self.get_list_choice(essayId, list_or_dict=None, key="essayId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_essay.content_essay_getbyid(**_kwargs)

        self.assert_content_essay_getbyid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="后台管理-内容审核1030-Y")
    def content_essay_updatestatus(self, _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/essay/updateStatus
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_essay.content_essay_updatestatus(**_kwargs)

        self.assert_content_essay_updatestatus(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="后台管理-评论信息1030-Y")
    def content_essay_getcommentlist(self, size=10, parentId="$None$", keyWord="$None$", commentId="$None$", endTime="$None$", checkedStatus="$None$", essayId="$None$", startTime="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/content/essay/getCommentList
                params: essayId :  : 文章主键
                params: keyWord :  : 关键词
                params: checkedStatus :  : 审核状态 审核状态 0待审核 1.已上架 2.审核未通过3：已下架 5已删除
                params: startTime :  : 开始时间
                params: endTime :  : 结束时间
                params: commentId :  : 评论id
                params: parentId :  : 父级id
                params: size :  : 每页数量
                params: current :  : 当前页
                params: headers : 请求头
        """
        parentId = self.get_list_choice(parentId, list_or_dict=None, key="parentId")
        keyWord = self.get_list_choice(keyWord, list_or_dict=None, key="keyWord")
        commentId = self.get_list_choice(commentId, list_or_dict=None, key="commentId")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        checkedStatus = self.get_list_choice(checkedStatus, list_or_dict=None, key="checkedStatus")
        essayId = self.get_list_choice(essayId, list_or_dict=None, key="essayId")
        startTime = self.get_list_choice(startTime, list_or_dict=None, key="startTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_essay.content_essay_getcommentlist(**_kwargs)

        self.assert_content_essay_getcommentlist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.asserts_essay import AssertsEssay
from service.app_a.apis import apis_essay


class FunsEssay(AssertsEssay):
    @allure.step(title="文章-批量操作-Y")
    def essay_batch(self, essayId="$None$", batchType="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/essay/batch
                params: essayId :  : 文章主键
                params: batchType :  : 1：归档2：撤回3：置顶4：取消置顶
                params: headers : 请求头
        """
        essayId = self.get_value_choice(essayId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        batchType = self.get_value_choice(batchType, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_essay.essay_batch(**_kwargs)

        self.assert_essay_batch(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="文章-获取列表状态数量-Y")
    def essay_querylistcount(self, subjectId="$None$", keyWord="$None$", endTime="$None$", status="$None$", author="$None$", essayId="$None$", startTime="$None$", _assert=True,  **kwargs):
        """
            url=/essay/queryListCount
                params: essayId :  : 文章主键
                params: keyWord :  : 搜索关键字
                params: author :  : 作者
                params: startTime :  : 搜索起始时间
                params: endTime :  : 搜索结束时间
                params: subjectId :  : 专题主键
                params: status :  : 状态
                params: headers : 请求头
        """
        subjectId = self.get_list_choice(subjectId, list_or_dict=None, key="subjectId")
        keyWord = self.get_list_choice(keyWord, list_or_dict=None, key="keyWord")
        endTime = self.get_list_choice(endTime, list_or_dict=None, key="endTime")
        status = self.get_list_choice(status, list_or_dict=None, key="status")
        author = self.get_list_choice(author, list_or_dict=None, key="author")
        essayId = self.get_list_choice(essayId, list_or_dict=None, key="essayId")
        startTime = self.get_list_choice(startTime, list_or_dict=None, key="startTime")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_essay.essay_querylistcount(**_kwargs)

        self.assert_essay_querylistcount(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.radarpoints.userpoints.asserts_radarpoints_userpoints_pointsinfo import AssertsRadarpointsUserpointsPointsinfo
from service.app_a.apis.radarpoints.userpoints import apis_radarpoints_userpoints_pointsinfo


class FunsRadarpointsUserpointsPointsinfo(AssertsRadarpointsUserpointsPointsinfo):
    @allure.step(title="用户中心-积分明细-分页查询")
    def radarpoints_userpoints_pointsinfo_pagelist(self, userId="$None$", current=1, size=10, name="$None$", changeTimeBegin="$None$", businessSceneType="$None$", changeTimeEnd="$None$", _assert=True,  **kwargs):
        """
            url=/radarpoints/userPoints/pointsInfo/pageList
                params: size :  : 每页大小
                params: current :  : 当前页
                params: businessSceneType :  : 10001 转介裂变
                10002 营销活动
                10003 社区活跃
                10004 线下活动
                10005 用车行为
                10006 评价
                10007 内容奖励
                10008 后台管理手动操作
                20000 其他
                params: name :  : 名称
                params: changeTimeBegin :  : 变动开始时间
                params: changeTimeEnd :  : 变动结束时间
                params: headers : 请求头
        """
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")
        name = self.get_list_choice(name, list_or_dict=None, key="name")
        changeTimeBegin = self.get_list_choice(changeTimeBegin, list_or_dict=None, key="changeTimeBegin")
        businessSceneType = self.get_list_choice(businessSceneType, list_or_dict=None, key="businessSceneType")
        changeTimeEnd = self.get_list_choice(changeTimeEnd, list_or_dict=None, key="changeTimeEnd")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_userpoints_pointsinfo.radarpoints_userpoints_pointsinfo_pagelist(**_kwargs)

        self.assert_radarpoints_userpoints_pointsinfo_pagelist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.radarpoints.adjustpoints.adjust.asserts_radarpoints_adjustpoints_adjust_single import AssertsRadarpointsAdjustpointsAdjustSingle
from service.app_a.apis.radarpoints.adjustpoints.adjust import apis_radarpoints_adjustpoints_adjust_single


class FunsRadarpointsAdjustpointsAdjustSingle(AssertsRadarpointsAdjustpointsAdjustSingle):
    @allure.step(title="积分调整 - 单次调整")
    def radarpoints_adjustpoints_adjust_single_save(self, userId="$None$", clientNotes="$None$", adjustNotes="$None$", pointsExpiration="$None$", qty="$None$", optAbility="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/radarpoints/adjustPoints/adjust/single/save
                params: optAbility : number : 积分调整类型
                params: adjustNotes : string : 调整原因说明
                params: clientNotes : string : 户端展示信息
                params: qty : number : 调整数值
                params: pointsExpiration : number : 积分有效期类型（新增时赋值）
                params: headers : 请求头
        """
        userId = self.get_value_choice(userId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        clientNotes = self.get_value_choice(clientNotes, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        adjustNotes = self.get_value_choice(adjustNotes, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        pointsExpiration = self.get_value_choice(pointsExpiration, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        qty = self.get_value_choice(qty, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        optAbility = self.get_value_choice(optAbility, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_adjustpoints_adjust_single.radarpoints_adjustpoints_adjust_single_save(**_kwargs)

        self.assert_radarpoints_adjustpoints_adjust_single_save(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.content.asserts_content_campmanager import AssertsContentCampmanager
from service.app_a.apis.content import apis_content_campmanager


class FunsContentCampmanager(AssertsContentCampmanager):
    @allure.step(title="营地服务列表 - 分页查询")
    def content_campmanager_page(self, sortBody="$None$", name="$None$", id="$None$", sortord="$None$", createBy="$None$", status="$None$", _assert=True,  **kwargs):
        """
            url=/content/campManager/page
                params: id :  :
                params: name :  :
                params: status :  :
                params: createBy :  :
                params: sortBody :  :
                params: sortord :  : ASC/DESC/asc/desc
                params: headers : 请求头
        """
        sortBody = self.get_list_choice(sortBody, list_or_dict=None, key="sortBody")
        name = self.get_list_choice(name, list_or_dict=None, key="name")
        id = self.get_list_choice(id, list_or_dict=None, key="id")
        sortord = self.get_list_choice(sortord, list_or_dict=None, key="sortord")
        createBy = self.get_list_choice(createBy, list_or_dict=None, key="createBy")
        status = self.get_list_choice(status, list_or_dict=None, key="status")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_campmanager.content_campmanager_page(**_kwargs)

        self.assert_content_campmanager_page(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="营地列表 - 下架/批量下架")
    def content_campmanager_soldout(self, id="$None$", campId="$None$", _assert=True,  **kwargs):
        """
            url=/content/campManager/soldOut
                params: id :  :
                params: campId : array : 营地服务ID
                type : string : None
                params: headers : 请求头
        """
        id = self.get_value_choice(id, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        campId = self.get_value_choice(campId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_campmanager.content_campmanager_soldout(**_kwargs)

        self.assert_content_campmanager_soldout(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="新增营地 - 新增营地ID带出")
    def content_campmanager_insertcampid(self, _assert=True,  **kwargs):
        """
            url=/content/campManager/insertCampID
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_campmanager.content_campmanager_insertcampid(**_kwargs)

        self.assert_content_campmanager_insertcampid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="新增营地")
    def content_campmanager_insert(self, city="$None$", campDetail="$None$", name="$None$", url="$None$", province="$None$", discountExpEndTime="$None$", discountExpBeginTime="$None$", id="$None$", campTradeTime="$None$", county="$None$", ownerDiscount="$None$", content="$None$", address="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/campManager/insert
                params: id : text : 营地服务ID
                params: name : text : 营地名称
                params: content : text : 营地简介
                params: url : text : 营地图片
                params: campDetail : text : 营地详情
                params: ownerDiscount : text : 车主优惠
                params: campTradeTime : text : 营地营业时间
                params: discountExpBeginTime : text : 车主优惠有效期 - 开始时间
                params: discountExpEndTime : text : 车主优惠有效期 - 结束时间
                params: province : text : 省
                params: city : text : 市
                params: county : text : 区/县
                params: address : text : 详细地址
                params: headers : 请求头
        """
        city = self.get_value_choice(city, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        campDetail = self.get_value_choice(campDetail, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        name = self.get_value_choice(name, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        url = self.get_value_choice(url, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        province = self.get_value_choice(province, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        discountExpEndTime = self.get_value_choice(discountExpEndTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        discountExpBeginTime = self.get_value_choice(discountExpBeginTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        id = self.get_value_choice(id, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        campTradeTime = self.get_value_choice(campTradeTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        county = self.get_value_choice(county, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        ownerDiscount = self.get_value_choice(ownerDiscount, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        content = self.get_value_choice(content, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        address = self.get_value_choice(address, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_campmanager.content_campmanager_insert(**_kwargs)

        self.assert_content_campmanager_insert(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="营地列表 - 营地详情")
    def content_campmanager_detail_(self, id="$None$", _assert=True,  **kwargs):
        """
            url=/content/campManager/detail/{id}
                params: id :  : 营地服务ID
                params: headers : 请求头
        """
        id = self.get_list_choice(id, list_or_dict=None, key="id")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_campmanager.content_campmanager_detail_(**_kwargs)

        self.assert_content_campmanager_detail_(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="编辑营地")
    def content_campmanager_update(self, phone="$None$", discountExpEndTime="$None$", discountExpBeginTime="$None$", ownerDiscount="$None$", areaCode="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/campManager/update
                params: ownerDiscount : text : 车主优惠
                params: discountExpBeginTime : text : 车主优惠有效期 - 开始时间
                params: discountExpEndTime : text : 车主优惠有效期 - 结束时间
                params: areaCode : text : 区号
                params: phone : text : 手机号
                params: headers : 请求头
        """
        phone = self.get_value_choice(phone, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        discountExpEndTime = self.get_value_choice(discountExpEndTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        discountExpBeginTime = self.get_value_choice(discountExpBeginTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        ownerDiscount = self.get_value_choice(ownerDiscount, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        areaCode = self.get_value_choice(areaCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_campmanager.content_campmanager_update(**_kwargs)

        self.assert_content_campmanager_update(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.admin.asserts_admin_guc import AssertsAdminGuc
from service.app_a.apis.admin import apis_admin_guc


class FunsAdminGuc(AssertsAdminGuc):
    @allure.step(title="guc登出")
    def admin_guc_guclogout(self, _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/admin/guc/gucLogout
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_admin_guc.admin_guc_guclogout(**_kwargs)

        self.assert_admin_guc_guclogout(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="guc登录回调")
    def admin_guc_guclogin(self, _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/admin/guc/gucLogin
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_admin_guc.admin_guc_guclogin(**_kwargs)

        self.assert_admin_guc_guclogin(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_activitymanager import SqlsContentActivitymanager


class AssertsContentActivitymanager(SqlsContentActivitymanager):
    @allure.step(title="接口返回结果校验")
    def assert_content_activitymanager_updateperson(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_activitymanager_updateperson(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["needLimitPeople", "limitPeople", "activityId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_activitymanager_updateenrolltime(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_activitymanager_updateenrolltime(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["enrollStartTime", "enrollTime", "activityId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_activitymanager_page(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_activitymanager_page(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["target", "city", "activityId", "province", "endTime", "pushTimeSort", "title", "status", "activityTimeSort", "beginTime", "createTimeSort"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_activitymanager_actinfoupdate(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_activitymanager_actinfoupdate(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["operationType", "activityId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_activitymanager_setactivitysort(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_activitymanager_setactivitysort(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["activityId", "sort"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_activitymanager_getactivityinfo_(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_activitymanager_getactivityinfo_(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["activityId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_activitymanager_activitytop_(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_activitymanager_activitytop_(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["topFlag", "activityId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_activitymanager_activityjoinuserexport(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_activitymanager_activityjoinuserexport(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["activityId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_activitymanager_save(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_activitymanager_save(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["reason", "endTime", "enrollStartTime", "county", "content", "limitPeople", "beginTime", "activityAddr", "agreementId", "coordinate", "publishType", "title", "status", "customerGroup", "activityPicUrl", "needLimitPeople", "activityId", "province", "activityPicURL", "enrollTime", "needArea", "city", "authId", "publishTime"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_activitymanager_update(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_activitymanager_update(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["reason", "endTime", "enrollStartTime", "county", "content", "limitPeople", "beginTime", "activityAddr", "coordinate", "publishType", "title", "status", "customerGroup", "activityPicUrl", "needLimitPeople", "activityId", "province", "activityPicURL", "enrollTime", "city", "needArea", "authId", "publishTime"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_activitymanager_publishupdate(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_activitymanager_publishupdate(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["activityId", "status", "publishStatus", "activityIds"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_activitymanager_statusupdate(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_activitymanager_statusupdate(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["activityIds", "checkStatus"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_activitymanager_enrollupdate(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_activitymanager_enrollupdate(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["checkEnroll", "activityIds"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_activitymanager_activityexport(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_activitymanager_activityexport(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["target", "city", "activityId", "province", "endTime", "pushTimeSort", "title", "status", "activityTimeSort", "beginTime", "createTimeSort"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_activitymanager_listlog(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_activitymanager_listlog(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["activityId"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_noticemanager import SqlsContentNoticemanager


class AssertsContentNoticemanager(SqlsContentNoticemanager):
    @allure.step(title="接口返回结果校验")
    def assert_content_noticemanager_page(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_noticemanager_page(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_noticemanager_getnoticeparamslist_(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_noticemanager_getnoticeparamslist_(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["messageId", "templateType"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_noticemanager_noticeparamsupdate(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_noticemanager_noticeparamsupdate(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["templateName", "templateContent", "templateType"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import unit_request
from service.app_a.sqls.common.sqls_common_systemversion import SqlsCommonSystemversion


class AssertsCommonSystemversion(SqlsCommonSystemversion):
    @allure.step(title="接口返回结果校验")
    def assert_common_systemversion_save(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_systemversion_save(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["remark", "name", "force", "version", "downloadUrl", "versionId", "content", "publishStatus", "classify"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_systemversion_page(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_systemversion_page(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import unit_request
from service.app_a.sqls.sqls_testdrive import SqlsTestdrive


class AssertsTestdrive(SqlsTestdrive):
    @allure.step(title="接口返回结果校验")
    def assert_testdrive_subscribe(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_testdrive_subscribe(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["appointmentTime", "shopName", "phoneNumber", "channel", "leadSourceCode", "model", "shopId", "activityCode", "customerName", "modelId", "leadSanSourceCode"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/activityManager/updatePerson")
def content_activitymanager_updateperson(needLimitPeople=None, limitPeople=None, activityId=None, headers=None, **kwargs):
    """
    活动 -修改报名人数(930)-Y
    up_time=1675238032

    params: activityId : string : 活动Id
    params: needLimitPeople : string : 是否限制 0 不限制 1限制
    params: limitPeople : number : 限制人数
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/activityManager/updatePerson"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "activityId": activityId,  # 活动Id
        "needLimitPeople": needLimitPeople,  # 是否限制 0 不限制 1限制
        "limitPeople": limitPeople,  # 限制人数
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/activityManager/updateEnrollTime")
def content_activitymanager_updateenrolltime(enrollStartTime=None, enrollTime=None, activityId=None, headers=None, **kwargs):
    """
    活动 -修改报名时间-Y
    up_time=1675238090

    params: activityId : string : 活动Id
    params: enrollStartTime : string : 报名开始时间
    params: enrollTime : string : 报名结束时间
    params: headers : 请求头
    ====================返回======================
    params: code : number : 编码
    params: msg : string : 信息
    params: data : boolean : 数据
    """
    _method = "POST"
    _url = "/content/activityManager/updateEnrollTime"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "activityId": activityId,  # 活动Id
        "enrollStartTime": enrollStartTime,  # 报名开始时间
        "enrollTime": enrollTime,  # 报名结束时间
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/activityManager/page")
def content_activitymanager_page(target=None, city=None, activityId=None, province=None, endTime=None, pushTimeSort=None, title=None, status=None, activityTimeSort=None, beginTime=None, createTimeSort=None, headers=None, **kwargs):
    """
    活动列表查询（930版本）-Y
    up_time=1675147665

    params: activityId :  : 
    params: title :  : 
    params: beginTime :  : 2022-01-18 00:00:00 （一定要带上00:00:00）
    params: endTime :  : 2022-01-18 23:59:59 （一定要带上23:59:59）
    params: target :  : 1：全部用户,2：车主用户,3：非车主用户,4:使用人,5：车主&使用人,6：非车主&非使用人
    params: status :  : 活动状态: 不传查全部， 2.待审核  4.待发布 5.已发布 6.审核不过 7.已撤回 8.已归档 9.停止报名 10.已结束 11.已下架  ；查询时候传的状态：12.已删除
    params: province :  : 省（编码 areaId）全国则不需要传值
    params: city :  : 市（编码areaId）
    params: createTimeSort :  : 创建时间排序（DESC（倒序））|ASC（正序））
    params: activityTimeSort :  : 活动时间排序（DESC|ASC）
    params: pushTimeSort :  : 发布时间排序（DESC|ASC）
    params: headers : 请求头
    ====================返回======================
    params: code : number : 接口状态
    params: msg : string : 提示信息
    params: data : object : 
              records : array : 
              total : number : 总数量
              pageSize : number : 分页大小
              pageNum : number : 当前页码
              pages : number : 总页数
              nextPage : number : 下一页
              size : number : 当前页的数量
              proPage : number : 上一页
              checkWaitStatusCount : number : 待审核数量
              publishWaitStatusCount : number : 待发布数量
    """
    _method = "GET"
    _url = "/content/activityManager/page"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "activityId": activityId,
        "title": title,
        "beginTime": beginTime,  # 2022-01-18 00:00:00 （一定要带上00:00:00）
        "endTime": endTime,  # 2022-01-18 23:59:59 （一定要带上23:59:59）
        "target": target,  # 1：全部用户,2：车主用户,3：非车主用户,4:使用人,5：车主&使用人,6：非车主&非使用人
        "status": status,  # 活动状态: 不传查全部， 2.待审核  4.待发布 5.已发布 6.审核不过 7.已撤回 8.已归档 9.停止报名 10.已结束 11.已下架  ；查询时候传的状态：12.已删除
        "province": province,  # 省（编码 areaId）全国则不需要传值
        "city": city,  # 市（编码areaId）
        "createTimeSort": createTimeSort,  # 创建时间排序（DESC（倒序））|ASC（正序））
        "activityTimeSort": activityTimeSort,  # 活动时间排序（DESC|ASC）
        "pushTimeSort": pushTimeSort,  # 发布时间排序（DESC|ASC）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/activityManager/actInfoUpdate")
def content_activitymanager_actinfoupdate(operationType=None, activityId=None, headers=None, **kwargs):
    """
    活动操作停止报名和结束活动-Y
    up_time=1675393449

    params: activityId : text : 活动ID
    params: operationType : text : 1停止报名 2活动结束
    params: headers : 请求头
    ====================返回======================
    params: code : number : 0成功
    params: msg : string : 描述
    params: data : boolean : true成功
    """
    _method = "POST"
    _url = "/content/activityManager/actInfoUpdate"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "activityId": activityId,  # 活动ID
        "operationType": operationType,  # 1停止报名 2活动结束
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/activityManager/setActivitySort")
def content_activitymanager_setactivitysort(activityId=None, sort=None, headers=None, **kwargs):
    """
    设置活动权重(930版本)-Y
    up_time=1675237750

    params: activityId : string : 活动Id
    params: sort : number : 权重
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/activityManager/setActivitySort"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "activityId": activityId,  # 活动Id
        "sort": sort,  # 权重
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/activityManager/getActivityInfo/")
def content_activitymanager_getactivityinfo_(activityId=None, headers=None, **kwargs):
    """
    获取活动详情-Y
    up_time=1678256790

    params: activityId :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              activityId : string : 活动ID
              createTime : string : 创建时间
              createBy : string : 创建人
              createByName : ['string', 'null'] : 创建人名称
              mobile : ['string', 'null'] : 手机号
              avatar : ['string', 'null'] : 头像
              username : ['string', 'null'] : 用户名称
              userType : ['number', 'null'] : 用户类型：2：内部用户3：虚拟用户
              activityPicUrl : ['string', 'null'] : 活动封面图
              title : string : 标题
              joinCnt : string : 参加人数
              activityJoinList : array : 活动参与人数数据集合
              content : string : 活动简介
              beginTime : string : 开始时间
              endTime : string : 结束时间
              needArea : string : 需要区域：0不需要 1需要
              province : ['null', 'string'] : 省
              city : ['null', 'string'] : 市
              county : ['null', 'string'] : 区
              activityAddr : string : 活动地址
              reason : string : 原因
              publishType : integer : 
              status : number : 状态: 1.新建 2.待审核 3.审核通过 4.待发布 5.已发布 6.审核不过  7.已撤回 8.已归档；查询时候传的状态：9.停止报名 10.已结束
              statusName : ['string', 'null'] : 状态名称
              authId : number : 作者ID
              enrollStartTime : string : 报名开始时间
              enrollTime : string : 报名截止时间
              needLimitPeople : string : 需要人数限制（活动人数）：0不需要 1需要
              limitPeople : integer : 人数限制
              customerGroup : string : 参与对象（1：全部用户，2：车主用户，3：非车主用户）
     * 1：全部用户,2：车主用户,3：非车主用户,4:使用人,5：车主&使用人,6：非车主&非使用人
              checkTime : string : 审核时间
              publishTime : string : 发布时间
              topFlag : integer : 置顶
              sort : integer : 权重
              activityCreateUser : string : 活动创建者ID
              agreementId : string : 协议id
              agreementName : string : 协议名称
              agreementCode : string : 协议编码
    """
    _method = "GET"
    _url = "/content/activityManager/getActivityInfo/{activityId}"
    _url = get_url(_url, locals())

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
        "activityId": activityId,
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/activityManager/activityTop/")
def content_activitymanager_activitytop_(topFlag=None, activityId=None, headers=None, **kwargs):
    """
    活动置顶/取消置顶-Y
    up_time=1675238359

    params: activityId : text : 活动ID
    params: topFlag : text : 0不置顶  1置顶
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/activityManager/activityTop/"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "activityId": activityId,  # 活动ID
        "topFlag": topFlag,  # 0不置顶  1置顶
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/activityManager/activityJoinUserExport")
def content_activitymanager_activityjoinuserexport(activityId=None, headers=None, **kwargs):
    """
    活动报名用户数据导出-Y
    up_time=1675238544

    params: activityId :  : 活动Id
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/content/activityManager/activityJoinUserExport"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "activityId": activityId,  # 活动Id
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/activityManager/save")
def content_activitymanager_save(reason=None, endTime=None, enrollStartTime=None, county=None, content=None, limitPeople=None, beginTime=None, activityAddr=None, agreementId=None, coordinate=None, publishType=None, title=None, status=None, customerGroup=None, activityPicUrl=None, needLimitPeople=None, activityId=None, province=None, activityPicURL=None, enrollTime=None, needArea=None, city=None, authId=None, publishTime=None, headers=None, **kwargs):
    """
    活动新增-Y
    up_time=1678257957

    params: activityId : text : 
    params: title : text : 
    params: reason : text : 
    params: activityPicUrl : text : 
    params: beginTime : text : 
    params: endTime : text : 汉字
    params: needArea : text : 汉字
    params: province : text : 汉字
    params: city : text : 34.232342,112.342345
    params: county : text : 
    params: coordinate : text : 
    params: needLimitPeople : text : 
    params: limitPeople : text : 
    params: enrollStartTime : text : 
    params: enrollTime : text : 
    params: publishType : text : 地图获取
    params: publishTime : text : 
    params: content : text : 
    params: authId : text : 
    params: status : text : 
    params: activityAddr : text : 
    params: customerGroup : text : 
    params: activityPicURL : string : 活动封面图
    params: agreementId : number : 协议ID
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/activityManager/save"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "activityId": activityId,
        "title": title,
        "reason": reason,
        "activityPicUrl": activityPicUrl,
        "beginTime": beginTime,
        "endTime": endTime,  # 汉字
        "needArea": needArea,  # 汉字
        "province": province,  # 汉字
        "city": city,  # 34.232342,112.342345
        "county": county,
        "coordinate": coordinate,
        "needLimitPeople": needLimitPeople,
        "limitPeople": limitPeople,
        "enrollStartTime": enrollStartTime,
        "enrollTime": enrollTime,
        "publishType": publishType,  # 地图获取
        "publishTime": publishTime,
        "content": content,
        "authId": authId,
        "status": status,
        "activityAddr": activityAddr,
        "customerGroup": customerGroup,
        "activityPicURL": activityPicURL,  # 活动封面图
        "agreementId": agreementId,  # 协议ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/activityManager/update")
def content_activitymanager_update(reason=None, endTime=None, enrollStartTime=None, county=None, content=None, limitPeople=None, beginTime=None, activityAddr=None, coordinate=None, publishType=None, title=None, status=None, customerGroup=None, activityPicUrl=None, needLimitPeople=None, activityId=None, province=None, activityPicURL=None, enrollTime=None, city=None, needArea=None, authId=None, publishTime=None, headers=None, **kwargs):
    """
    活动编辑（930版本）-Y
    up_time=1675237616

    params: activityId : text : 
    params: title : text : 
    params: reason : text : 
    params: activityPicUrl : text : 
    params: beginTime : text : 
    params: endTime : text : 
    params: province : text : 汉字
    params: city : text : 汉字
    params: county : text : 
    params: coordinate : text : 34.232342,112.342345
    params: limitPeople : text : 
    params: enrollTime : text : 
    params: publishType : text : 
    params: publishTime : text : 
    params: content : text : 
    params: authId : text : 
    params: activityPicURL : string : 活动封面图
    params: needArea : string : 是否需要区域
    params: needLimitPeople : string : 是否需要人数限制
    params: enrollStartTime : string : 报名开始时间
    params: status : integer : 活动状态: 不传查全部
     * 2:待审核
     * 3:审核通过
     * 4:待上架
     * 5:已上架
     * 6:审核不通过
     * 9:停止报名
     * 10:已结束
     * 11:已下架
     * 12:已删除
    params: activityAddr : string : 活动地址
    params: customerGroup : string : 参与对象（1：全部用户，2：车主用户，3：非车主用户）
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/activityManager/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "activityId": activityId,
        "title": title,
        "reason": reason,
        "activityPicUrl": activityPicUrl,
        "beginTime": beginTime,
        "endTime": endTime,
        "province": province,  # 汉字
        "city": city,  # 汉字
        "county": county,
        "coordinate": coordinate,  # 34.232342,112.342345
        "limitPeople": limitPeople,
        "enrollTime": enrollTime,
        "publishType": publishType,
        "publishTime": publishTime,
        "content": content,
        "authId": authId,
        "activityPicURL": activityPicURL,  # 活动封面图
        "needArea": needArea,  # 是否需要区域
        "needLimitPeople": needLimitPeople,  # 是否需要人数限制
        "enrollStartTime": enrollStartTime,  # 报名开始时间
        "status": status,  # 活动状态: 不传查全部      * 2:待审核      * 3:审核通过      * 4:待上架      * 5:已上架      * 6:审核不通过      * 9:停止报名      * 10:已结束      * 11:已下架      * 12:已删除
        "activityAddr": activityAddr,  # 活动地址
        "customerGroup": customerGroup,  # 参与对象（1：全部用户，2：车主用户，3：非车主用户）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/activityManager/publishUpdate")
def content_activitymanager_publishupdate(activityId=None, status=None, publishStatus=None, activityIds=None, headers=None, **kwargs):
    """
    活动发布状态修改(930)-Y
    up_time=1675392693

    params: activityIds : text : 单个记录修改传["xxxxx"]
    params: publishStatus : text : 
    params: activityId : string : 活动Id
    params: status : number : //状态: 1.新建 2.待审核 3.审核通过 4.待发布 5.已发布 6.审核不过 7.已撤回 8.已归档 9.停止报名 10.已结束 11.已下架；查询时候传的状态：12.已删除
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/activityManager/publishUpdate"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "activityIds": activityIds,  # 单个记录修改传["xxxxx"]
        "publishStatus": publishStatus,
        "activityId": activityId,  # 活动Id
        "status": status,  # //状态: 1.新建 2.待审核 3.审核通过 4.待发布 5.已发布 6.审核不过 7.已撤回 8.已归档 9.停止报名 10.已结束 11.已下架；查询时候传的状态：12.已删除
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/activityManager/statusUpdate")
def content_activitymanager_statusupdate(activityIds=None, checkStatus=None, headers=None, **kwargs):
    """
    活动审核状态修改-Y
    up_time=1675392843

    params: checkStatus : text : 
    params: activityIds : array : 活动IDs
              type : string : None
    params: headers : 请求头
    ====================返回======================
    params: code : string : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/activityManager/statusUpdate"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "checkStatus": checkStatus,
        "activityIds": activityIds,  # 活动IDs
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/activityManager/enrollUpdate")
def content_activitymanager_enrollupdate(checkEnroll=None, activityIds=None, headers=None, **kwargs):
    """
    活动报名状态修改-Y
    up_time=1675393335

    params: activityIds : text : 单个记录修改传["xxxxx"]
    params: checkEnroll : text : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/activityManager/enrollUpdate"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "activityIds": activityIds,  # 单个记录修改传["xxxxx"]
        "checkEnroll": checkEnroll,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/activityManager/activityExport")
def content_activitymanager_activityexport(target=None, city=None, activityId=None, province=None, endTime=None, pushTimeSort=None, title=None, status=None, activityTimeSort=None, beginTime=None, createTimeSort=None, headers=None, **kwargs):
    """
    活动数据导出-Y
    up_time=1675149098

    params: activityId :  : 
    params: title :  : 
    params: beginTime :  : 2022-01-18 00:00:00 （一定要带上00:00:00）
    params: endTime :  : 2022-01-18 23:59:59 （一定要带上23:59:59）
    params: target :  : 1：全部用户,2：车主用户,3：非车主用户,4:使用人,5：车主&使用人,6：非车主&非使用人
    params: status :  : 活动状态: 不传查全部， 2.待审核  4.待发布 5.已发布 6.审核不过 7.已撤回 8.已归档 9.停止报名 10.已结束 11.已下架  ；查询时候传的状态：12.已删除
    params: province :  : 省（编码 areaId）全国则不需要传值
    params: city :  : 市（编码areaId）
    params: createTimeSort :  : 创建时间排序（DESC（倒序））|ASC（正序））
    params: activityTimeSort :  : 活动时间排序（DESC|ASC）
    params: pushTimeSort :  : 发布时间排序（DESC|ASC）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/content/activityManager/activityExport"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "activityId": activityId,
        "title": title,
        "beginTime": beginTime,  # 2022-01-18 00:00:00 （一定要带上00:00:00）
        "endTime": endTime,  # 2022-01-18 23:59:59 （一定要带上23:59:59）
        "target": target,  # 1：全部用户,2：车主用户,3：非车主用户,4:使用人,5：车主&使用人,6：非车主&非使用人
        "status": status,  # 活动状态: 不传查全部， 2.待审核  4.待发布 5.已发布 6.审核不过 7.已撤回 8.已归档 9.停止报名 10.已结束 11.已下架  ；查询时候传的状态：12.已删除
        "province": province,  # 省（编码 areaId）全国则不需要传值
        "city": city,  # 市（编码areaId）
        "createTimeSort": createTimeSort,  # 创建时间排序（DESC（倒序））|ASC（正序））
        "activityTimeSort": activityTimeSort,  # 活动时间排序（DESC|ASC）
        "pushTimeSort": pushTimeSort,  # 发布时间排序（DESC|ASC）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/activityManager/listLog")
def content_activitymanager_listlog(activityId=None, headers=None, **kwargs):
    """
    活动状态流程-Y
    up_time=1675648649

    params: activityId :  : 活动id
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : array : 
              activityLogId : number : 日志主键
              activityId : string : 活动主键
              lastStatus : string : 之前的状态
              lastStatusName : integer : 之前的状态名称
              currentStatus : integer : 当前状态
              currentStatusName : string : 当前状态名称
              userId : number : 用户ID
              userName : string : 用户名称
              time : string : 时间
              reason : string : 原因
    """
    _method = "GET"
    _url = "/content/activityManager/listLog"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "activityId": activityId,  # 活动id
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/radarpoints/adjustPoints/adjust/single/save")
def radarpoints_adjustpoints_adjust_single_save(userId=None, clientNotes=None, adjustNotes=None, pointsExpiration=None, qty=None, optAbility=None, headers=None, **kwargs):
    """
    积分调整 - 单次调整
    up_time=1677216484

    params: optAbility : number : 积分调整类型
    params: adjustNotes : string : 调整原因说明
    params: clientNotes : string : 户端展示信息
    params: userId : number : 调整目标用户ID
    params: qty : number : 调整数值
    params: pointsExpiration : number : 积分有效期类型（新增时赋值）
    params: headers : 请求头
    ====================返回======================
    params: code : number : 200：成功，其他失败
    params: msg : string : 备注
    params: data : boolean : true/false
    """
    _method = "POST"
    _url = "/radarpoints/adjustPoints/adjust/single/save"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "optAbility": optAbility,  # 积分调整类型
        "adjustNotes": adjustNotes,  # 调整原因说明
        "clientNotes": clientNotes,  # 户端展示信息
        "userId": userId,  # 调整目标用户ID
        "qty": qty,  # 调整数值
        "pointsExpiration": pointsExpiration,  # 积分有效期类型（新增时赋值）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.order.rightsorder.asserts_order_rightsorder_receive import AssertsOrderRightsorderReceive
from service.app_a.apis.order.rightsorder import apis_order_rightsorder_receive


class FunsOrderRightsorderReceive(AssertsOrderRightsorderReceive):
    @allure.step(title="权益-编辑权益订单-Y")
    def order_rightsorder_receive_update(self, rightsId="$None$", rightsName="$None$", rightsType="$None$", userId="$None$", refundDate="$None$", createTime="$None$", receiveDate="$None$", refundBillNo="$None$", updateId="$None$", payBillNo="$None$", payDate="$None$", mobile="$None$", payAmount="$None$", createBy="$None$", rightsOrderId="$None$", updateTime="$None$", orderMainId="$None$", useStatus="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/order/rightsOrder/receive/update
                params: rightsOrderId : string :
                params: rightsId : string :
                params: rightsType : string :
                params: rightsName : string :
                params: orderMainId : string :
                params: mobile : string :
                params: payAmount : string :
                params: useStatus : string :
                params: receiveDate : string :
                params: payDate : string :
                params: refundDate : string :
                params: payBillNo : string :
                params: refundBillNo : string :
                params: createTime : string :
                params: createBy : string :
                params: updateTime : string :
                params: updateId : string :
                params: headers : 请求头
        """
        rightsId = self.get_value_choice(rightsId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        rightsName = self.get_value_choice(rightsName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        rightsType = self.get_value_choice(rightsType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        userId = self.get_value_choice(userId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        refundDate = self.get_value_choice(refundDate, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        createTime = self.get_value_choice(createTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        receiveDate = self.get_value_choice(receiveDate, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        refundBillNo = self.get_value_choice(refundBillNo, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        updateId = self.get_value_choice(updateId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        payBillNo = self.get_value_choice(payBillNo, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        payDate = self.get_value_choice(payDate, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        mobile = self.get_value_choice(mobile, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        payAmount = self.get_value_choice(payAmount, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        createBy = self.get_value_choice(createBy, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        rightsOrderId = self.get_value_choice(rightsOrderId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        updateTime = self.get_value_choice(updateTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        orderMainId = self.get_value_choice(orderMainId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        useStatus = self.get_value_choice(useStatus, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_rightsorder_receive.order_rightsorder_receive_update(**_kwargs)

        self.assert_order_rightsorder_receive_update(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/common/user/getUserVestList")
def common_user_getuservestlist( headers=None, **kwargs):
    """
    获取管理后台用户的小号（马甲）-Y
    up_time=1675649144

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : array : 
              id : string : 用户Id
              name : string : 用户昵称
    """
    _method = "GET"
    _url = "/common/user/getUserVestList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import unit_request
from service.app_a.sqls.radarpoints.adjustpoints.adjust.sqls_radarpoints_adjustpoints_adjust_batch import SqlsRadarpointsAdjustpointsAdjustBatch


class AssertsRadarpointsAdjustpointsAdjustBatch(SqlsRadarpointsAdjustpointsAdjustBatch):
    @allure.step(title="接口返回结果校验")
    def assert_radarpoints_adjustpoints_adjust_batch_save(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_radarpoints_adjustpoints_adjust_batch_save(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["file", "clientNotes", "adjustNotes", "redisKey", "optAbility", "optAbilityName"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_radarpoints_adjustpoints_adjust_batch_import(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_radarpoints_adjustpoints_adjust_batch_import(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["file", "clientNotes", "adjustNotes", "field_35", "list", "field_34"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a.asserts.goods.asserts_goods_carmodel import AssertsGoodsCarmodel
from service.app_a.apis.goods import apis_goods_carmodel


class FunsGoodsCarmodel(AssertsGoodsCarmodel):
    @allure.step(title="保存车型详细信息 - Y")
    def goods_carmodel_savemanagecarmodel(self, carDetailType="$None$", preToDepositEndTime="$None$", prePrice="$None$", sharePosters="$None$", price="$None$", preEndTime="$None$", carCode="$None$", brandName="$None$", modelName="$None$", modelId="$None$", modelCode="$None$", carName="$None$", depositStartTime="$None$", depositPriceContent="$None$", depositEndTime="$None$", carSimpleName="$None$", prePriceContent="$None$", status="$None$", promptDesc="$None$", preToDepositStartTime="$None$", preStartTime="$None$", version="$None$", carDetailPics="$None$", carDetailUrl="$None$", prePricePosters="$None$", sort="$None$", configCode="$None$", depositPrice="$None$", posters="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/goods/carmodel/saveManageCarModel
                params: carName : string : 车系名称
                params: brandName : string : 品牌名称
                params: version : string : 品牌代码
                params: carCode : string : 车系代码
                params: modelName : string : 车型名称
                params: modelCode : string : 车型代号
                params: carSimpleName : string : 车型销售名称
                params: configCode : string : 配置编码
                params: sort : number : 车型权重
                params: price : number : 基础零售价
                params: carDetailType : number : 车型详情类型 - 1:图片，2:H5连接
                params: carDetailUrl : string : 车型详情类型为2 h5跳转地址
                params: preStartTime : string : 预订开始时间
                params: preEndTime : string : 预订结束时间
                params: preToDepositStartTime : string : 预订转大定开始时间
                params: preToDepositEndTime : string : 预订转大定结束时间
                params: prePrice : number : 预订金价格
                params: prePriceContent : string : 预订权益内容
                params: depositStartTime : string : 大定开始时间
                params: depositEndTime : string : 大定结束时间
                params: depositPrice : number : 定金价格
                params: depositPriceContent : string : 定金权益内容
                params: posters : array : 爱车海报
                imageUrl : string : 图片地址
                modelId : string : 车型ID
                params: sharePosters : array : 分享海报
                imageUrl : string :
                modelId : string :
                params: carDetailPics : array : 车详情图片
                imageUrl : string :
                modelId : string :
                params: prePricePosters : array : 预订金海报
                imageUrl : string :
                modelId : string :
                params: promptDesc : string : 提示文案
                params: modelId : string : 车型ID
                params: status : number : 状态(0禁用1启用)
                params: headers : 请求头
        """
        carDetailType = self.get_value_choice(carDetailType, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        preToDepositEndTime = self.get_value_choice(preToDepositEndTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        prePrice = self.get_value_choice(prePrice, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        sharePosters = self.get_value_choice(sharePosters, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        price = self.get_value_choice(price, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        preEndTime = self.get_value_choice(preEndTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        carCode = self.get_value_choice(carCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        brandName = self.get_value_choice(brandName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        modelName = self.get_value_choice(modelName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        modelId = self.get_value_choice(modelId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        modelCode = self.get_value_choice(modelCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        carName = self.get_value_choice(carName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        depositStartTime = self.get_value_choice(depositStartTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        depositPriceContent = self.get_value_choice(depositPriceContent, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        depositEndTime = self.get_value_choice(depositEndTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        carSimpleName = self.get_value_choice(carSimpleName, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        prePriceContent = self.get_value_choice(prePriceContent, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        status = self.get_value_choice(status, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        promptDesc = self.get_value_choice(promptDesc, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        preToDepositStartTime = self.get_value_choice(preToDepositStartTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        preStartTime = self.get_value_choice(preStartTime, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        version = self.get_value_choice(version, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        carDetailPics = self.get_value_choice(carDetailPics, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        carDetailUrl = self.get_value_choice(carDetailUrl, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        prePricePosters = self.get_value_choice(prePricePosters, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        sort = self.get_value_choice(sort, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        configCode = self.get_value_choice(configCode, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        depositPrice = self.get_value_choice(depositPrice, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        posters = self.get_value_choice(posters, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_carmodel.goods_carmodel_savemanagecarmodel(**_kwargs)

        self.assert_goods_carmodel_savemanagecarmodel(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="删除车型-Y")
    def goods_carmodel_removebyid(self, modelId="$None$", _assert=True,  **kwargs):
        """
            url=/goods/carmodel/removeById
                params: modelId :  : 车型id
                params: headers : 请求头
        """
        modelId = self.get_list_choice(modelId, list_or_dict=None, key="modelId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_carmodel.goods_carmodel_removebyid(**_kwargs)

        self.assert_goods_carmodel_removebyid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="查询车型详细信息-Y")
    def goods_carmodel_getcarmodelmanagebyid(self, modelId="$None$", _assert=True,  **kwargs):
        """
            url=/goods/carmodel/getCarModelManageById
                params: modelId :  : 车型编码
                params: headers : 请求头
        """
        modelId = self.get_list_choice(modelId, list_or_dict=None, key="modelId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_carmodel.goods_carmodel_getcarmodelmanagebyid(**_kwargs)

        self.assert_goods_carmodel_getcarmodelmanagebyid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="车型列表-Y")
    def goods_carmodel_getmanagecarmodel(self, modelCode="$None$", size=10, carName="$None$", operator="$None$", version="$None$", carCode="$None$", brandName="$None$", modelName="$None$", status="$None$", current=1, _assert=True,  **kwargs):
        """
            url=/goods/carmodel/getManageCarModel
                params: current :  : 分页
                params: size :  : 分页
                params: modelName :  : 车型名称
                params: modelCode :  : 车型代号
                params: status :  : 0:待启用，1:启用，2:禁用 车型新增默认状态待启用，全部则不传值
                params: operator :  : 操作人
                params: brandName :  : 品牌名称
                params: version :  : 品牌编码
                params: carName :  : 车系名称
                params: carCode :  : 车型编码
                params: headers : 请求头
        """
        modelCode = self.get_list_choice(modelCode, list_or_dict=None, key="modelCode")
        carName = self.get_list_choice(carName, list_or_dict=None, key="carName")
        operator = self.get_list_choice(operator, list_or_dict=None, key="operator")
        version = self.get_list_choice(version, list_or_dict=None, key="version")
        carCode = self.get_list_choice(carCode, list_or_dict=None, key="carCode")
        brandName = self.get_list_choice(brandName, list_or_dict=None, key="brandName")
        modelName = self.get_list_choice(modelName, list_or_dict=None, key="modelName")
        status = self.get_list_choice(status, list_or_dict=None, key="status")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_carmodel.goods_carmodel_getmanagecarmodel(**_kwargs)

        self.assert_goods_carmodel_getmanagecarmodel(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="订单管理-查询可试驾车型-Y")
    def goods_carmodel_getmodelnamelist(self, _assert=True,  **kwargs):
        """
            url=/goods/carmodel/getModelNameList
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_carmodel.goods_carmodel_getmodelnamelist(**_kwargs)

        self.assert_goods_carmodel_getmodelnamelist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="车型下拉列表-Y")
    def goods_carmodel_getcarnamelist(self, _assert=True,  **kwargs):
        """
            url=/goods/carmodel/getCarNameList
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_goods_carmodel.goods_carmodel_getcarnamelist(**_kwargs)

        self.assert_goods_carmodel_getcarnamelist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.order.asserts_order_order import AssertsOrderOrder
from service.app_a.apis.order import apis_order_order


class FunsOrderOrder(AssertsOrderOrder):
    @allure.step(title="订单详情")
    def order_order_orderdetail(self, userId="$None$", orderStatus="$None$", pageNum=1, total="$None$", pageSize="$None$", orderId="$None$", _assert=True,  **kwargs):
        """
            url=/order/order/orderDetail{orderId}{userId}
                params: orderId :  : 订单主单Id
                params: orderStatus : string : 订单状态
                params: pageSize : number : 每页大小
                params: pageNum : number : 当前页
                params: total : number : 总数
                params: headers : 请求头
        """
        userId = self.get_list_choice(userId, list_or_dict=None, key="userId")
        orderStatus = self.get_list_choice(orderStatus, list_or_dict=None, key="orderStatus")
        total = self.get_list_choice(total, list_or_dict=None, key="total")
        pageSize = self.get_list_choice(pageSize, list_or_dict=None, key="pageSize")
        orderId = self.get_list_choice(orderId, list_or_dict=None, key="orderId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_order.order_order_orderdetail(**_kwargs)

        self.assert_order_order_orderdetail(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="订单提车-Y")
    def order_order_finish(self, orderId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/order/order/finish
                params: orderId : string : 主订单ID
                params: headers : 请求头
        """
        orderId = self.get_value_choice(orderId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_order.order_order_finish(**_kwargs)

        self.assert_order_order_finish(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="订单退款驳回-Y")
    def order_order_refundreject(self, orderId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/order/order/refundReject
                params: orderId : string : 主订单ID
                params: headers : 请求头
        """
        orderId = self.get_value_choice(orderId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_order_order.order_order_refundreject(**_kwargs)

        self.assert_order_order_refundreject(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/comment/updateStatus")
def content_comment_updatestatus(fromStatus=None, commentId=None, toStatus=None, commentType=None, headers=None, **kwargs):
    """
    评论-状态扭转（通用）-Y
    up_time=1675394720

    params: commentId :  : 评论主键
    params: commentType :  : 评论类型1：文章评论2：动态评论	
    params: fromStatus :  : 当前状态
    params: toStatus :  : 扭转状态
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/comment/updateStatus"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "commentId": commentId,  # 评论主键
        "commentType": commentType,  # 评论类型1：文章评论2：动态评论	
        "fromStatus": fromStatus,  # 当前状态
        "toStatus": toStatus,  # 扭转状态
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/comment/downLoad")
def content_comment_download(nickName=None, keyWord=None, contentCommentIds=None, endTime=None, EssayCommentIds=None, status=None, mobile=None, downloadType=None, startTime=None, headers=None, **kwargs):
    """
    评论-评论导出-Y
    up_time=1675649477

    params: mobile :  : 评论用户手机号
    params: nickName :  : 评论昵称
    params: keyWord :  : 搜索关键字
    params: startTime :  : 搜索起始时间
    params: endTime :  : 搜索结束时间
    params: status :  : 状态0.待审核 1.已审核 2.审核未通过3：已发布4：已屏蔽
    params: downloadType :  : 1：根据搜索条件导出2：多选导出
    params: EssayCommentIds :  : 文章评论主键，用英文,隔开
    params: contentCommentIds :  : 动态评论主键，用英文,隔开
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/content/comment/downLoad"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "mobile": mobile,  # 评论用户手机号
        "nickName": nickName,  # 评论昵称
        "keyWord": keyWord,  # 搜索关键字
        "startTime": startTime,  # 搜索起始时间
        "endTime": endTime,  # 搜索结束时间
        "status": status,  # 状态0.待审核 1.已审核 2.审核未通过3：已发布4：已屏蔽
        "downloadType": downloadType,  # 1：根据搜索条件导出2：多选导出
        "EssayCommentIds": EssayCommentIds,  # 文章评论主键，用英文,隔开
        "contentCommentIds": contentCommentIds,  # 动态评论主键，用英文,隔开
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/comment/commentTop")
def content_comment_commenttop(commentId=None, topFlag=None, commentType=None, headers=None, **kwargs):
    """
    评论-评论置顶（通用）-Y
    up_time=1675663979

    params: commentId : string : 评论主键
    params: commentType : number : 评论类型1：文章评论2：动态评论
    params: topFlag : number : 1：置顶0：取消置顶
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/comment/commentTop"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "commentId": commentId,  # 评论主键
        "commentType": commentType,  # 评论类型1：文章评论2：动态评论
        "topFlag": topFlag,  # 1：置顶0：取消置顶
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/comment/list")
def content_comment_list(size=None, nickName=None, keyWord=None, endTime=None, commentType=None, checkedStatus=None, mobile=None, essayId=None, startTime=None, current=None, headers=None, **kwargs):
    """
    后台管理-评论管理列表1030-Y
    up_time=1675394167

    params: nickName :  : 用户昵称 String
    params: keyWord :  : 搜索内容关键字  String
    params: startTime :  : 搜索开始时间 yyyy-MM-dd HH:mm:ss
    params: endTime :  : 搜索结束时间 yyyy-MM-dd HH:mm:ss
    params: size :  : 每页数量数
    params: current :  : 当前页
    params: commentType :  : 评论类型1：文章评论 2：动态 Integer
    params: checkedStatus :  : 审核状态 0待审核 1.已上架 2.审核未通过3：已发布 5已删除 Integer
    params: mobile :  : 电话 string
    params: essayId :  : 文章(资讯)主键 string
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 总页数
              size : number : 每页大小
              current : number : 当前页
              pages : number : 页数
    """
    _method = "GET"
    _url = "/content/comment/list"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "nickName": nickName,  # 用户昵称 String
        "keyWord": keyWord,  # 搜索内容关键字  String
        "startTime": startTime,  # 搜索开始时间 yyyy-MM-dd HH:mm:ss
        "endTime": endTime,  # 搜索结束时间 yyyy-MM-dd HH:mm:ss
        "size": size,  # 每页数量数
        "current": current,  # 当前页
        "commentType": commentType,  # 评论类型1：文章评论 2：动态 Integer
        "checkedStatus": checkedStatus,  # 审核状态 0待审核 1.已上架 2.审核未通过3：已发布 5已删除 Integer
        "mobile": mobile,  # 电话 string
        "essayId": essayId,  # 文章(资讯)主键 string
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/comment/delete")
def content_comment_delete(commentId=None, toStatus=None, commentType=None, headers=None, **kwargs):
    """
    评论-屏蔽评论-Y
    up_time=1675394437

    params: commentId : string : 评论主键
    params: commentType : number : 1：文章评论2：动态评论
    params: toStatus : string : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : null : 
    params: data : boolean : 
    """
    _method = "POST"
    _url = "/content/comment/delete"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "commentId": commentId,  # 评论主键
        "commentType": commentType,  # 1：文章评论2：动态评论
        "toStatus": toStatus,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/hotcity/list")
def content_hotcity_list( headers=None, **kwargs):
    """
    热门城市-Y
    up_time=1675390336

    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : array : 
              id : number : ID主键
              name : string : 城市名称
              areaId : number : 城市代码
    """
    _method = "GET"
    _url = "/content/hotcity/list"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_essay import SqlsContentEssay


class AssertsContentEssay(SqlsContentEssay):
    @allure.step(title="接口返回结果校验")
    def assert_content_essay_delete_(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essay_delete_(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["essayId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_essay_searchbykey(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essay_searchbykey(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["Key"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_essay_checklist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essay_checklist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["subjectId", "keyWord", "CreateTimeSortType", "endTime", "recommend", "PublishTimeSortType", "status", "author", "essayId", "StatusSortType", "startTime"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_essay_list(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essay_list(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["subjectId", "keyWord", "CreateTimeSortType", "endTime", "recommend", "PublishTimeSortType", "status", "author", "essayId", "StatusSortType", "startTime"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_essay_add(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essay_add(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["subjectId", "videoUrl", "essayType", "recommend", "essPicUrl", "publishType", "author", "essayId", "title", "content", "status", "publishTime"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_essay_createid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essay_createid(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_essay_getbyid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essay_getbyid(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["essayId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_essay_updatestatus(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essay_updatestatus(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_essay_getcommentlist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essay_getcommentlist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["parentId", "keyWord", "commentId", "endTime", "checkedStatus", "essayId", "startTime"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import unit_request
from service.app_a.sqls.common.sqls_common_userpointsmanage import SqlsCommonUserpointsmanage


class AssertsCommonUserpointsmanage(SqlsCommonUserpointsmanage):
    @allure.step(title="接口返回结果校验")
    def assert_common_userpointsmanage_userpointsexport(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_userpointsmanage_userpointsexport(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["logIds", "endTime", "mobile", "nickName", "beginTime"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_userpointsmanage_page(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_userpointsmanage_page(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["mobile", "nickName", "endTime", "beginTime"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_userpointsmanage_manualchangeuserpoints(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_userpointsmanage_manualchangeuserpoints(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["userId", "operatePoint", "operateType", "taskName", "operateMark", "pointChangType"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_common_userpointsmanage_beforepointsexport(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_common_userpointsmanage_beforepointsexport(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["logIds", "endTime", "mobile", "nickName", "beginTime"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a import unit_request
from service.app_a.sqls.radarpoints.sqls_radarpoints_pointsconfig import SqlsRadarpointsPointsconfig


class AssertsRadarpointsPointsconfig(SqlsRadarpointsPointsconfig):
    @allure.step(title="接口返回结果校验")
    def assert_radarpoints_pointsconfig_page(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_radarpoints_pointsconfig_page(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["code", "pointsBegin", "name", "pointsExpiration", "pointsEnd", "status", "businessSceneType"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_radarpoints_pointsconfig_insert(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_radarpoints_pointsconfig_insert(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["remark", "name", "points", "rulesPointsDayMax", "pointsExpiration", "bpmId", "userPointsDayMax", "toast", "businessSceneType"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_radarpoints_pointsconfig_update(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_radarpoints_pointsconfig_update(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["remark", "code", "name", "points", "rulesPointsDayMax", "pointsExpiration", "userPointsDayMax", "bpmId", "id", "toast", "businessSceneType"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_radarpoints_pointsconfig_updatestatusbyid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_radarpoints_pointsconfig_updatestatusbyid(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["id", "status"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a.asserts.radarpoints.asserts_radarpoints_summarystatistics import AssertsRadarpointsSummarystatistics
from service.app_a.apis.radarpoints import apis_radarpoints_summarystatistics


class FunsRadarpointsSummarystatistics(AssertsRadarpointsSummarystatistics):
    @allure.step(title="积分汇总统计-分页查询积分")
    def radarpoints_summarystatistics_pagelist(self, flowTimeEnd="$None$", size=10, current=1, flowTimeBefore="$None$", _assert=True,  **kwargs):
        """
            url=/radarpoints/summaryStatistics/pageList
                params: current :  :
                params: size :  :
                params: flowTimeBefore :  : 流水开始时间
                params: flowTimeEnd :  : 流水结束时间
                params: headers : 请求头
        """
        flowTimeEnd = self.get_list_choice(flowTimeEnd, list_or_dict=None, key="flowTimeEnd")
        flowTimeBefore = self.get_list_choice(flowTimeBefore, list_or_dict=None, key="flowTimeBefore")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_summarystatistics.radarpoints_summarystatistics_pagelist(**_kwargs)

        self.assert_radarpoints_summarystatistics_pagelist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="积分汇总统计 - 导出")
    def radarpoints_summarystatistics_export(self, flowTimebefore="$None$", flowTimeEnd="$None$", size=10, current=1, _assert=True,  **kwargs):
        """
            url=/radarpoints/summaryStatistics/export
                params: current :  :
                params: size :  :
                params: flowTimeEnd :  :
                params: flowTimebefore :  :
                params: headers : 请求头
        """
        flowTimebefore = self.get_list_choice(flowTimebefore, list_or_dict=None, key="flowTimebefore")
        flowTimeEnd = self.get_list_choice(flowTimeEnd, list_or_dict=None, key="flowTimeEnd")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_radarpoints_summarystatistics.radarpoints_summarystatistics_export(**_kwargs)

        self.assert_radarpoints_summarystatistics_export(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a.asserts.content.asserts_content_hotsearch import AssertsContentHotsearch
from service.app_a.apis.content import apis_content_hotsearch


class FunsContentHotsearch(AssertsContentHotsearch):
    @allure.step(title="热门搜索-修改权重-Y")
    def content_hotsearch_rank(self, kId="$None$", rank="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/hotSearch/rank
                params: kId : string : 主键id
                params: rank : string : 权重
                params: headers : 请求头
        """
        kId = self.get_value_choice(kId, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        rank = self.get_value_choice(rank, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_hotsearch.content_hotsearch_rank(**_kwargs)

        self.assert_content_hotsearch_rank(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="热门搜索-列表-Y")
    def content_hotsearch_list(self, kId="$None$", rank="$None$", _assert=True,  **kwargs):
        """
            url=/content/hotSearch/list
                params: kId : string : 主键id
                params: rank : string : 权重
                params: headers : 请求头
        """
        kId = self.get_list_choice(kId, list_or_dict=None, key="kId")
        rank = self.get_list_choice(rank, list_or_dict=None, key="rank")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_hotsearch.content_hotsearch_list(**_kwargs)

        self.assert_content_hotsearch_list(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="热门搜索-新增-Y")
    def content_hotsearch_insert(self, keyWord="$None$", point="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/hotSearch/insert
                params: keyWord : string : 关键词(城市名)
                params: point : string : 1 发现-搜索 4 活动定位
                params: headers : 请求头
        """
        keyWord = self.get_value_choice(keyWord, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        point = self.get_value_choice(point, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_hotsearch.content_hotsearch_insert(**_kwargs)

        self.assert_content_hotsearch_insert(_assert, **_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/manageapi/order/mainOrder/pageList")
def manageapi_order_mainorder_pagelist(createEndTime=None, orderStatus=None, extOrderStatus=None, mainOrderId=None, userName=None, extNum=None, size=None, channel=None, dealerCode=None, cityId=None, mobile=None, provinceId=None, orderId=None, createStartTime=None, orderType=None, modelId=None, current=None, headers=None, **kwargs):
    """
    订单管理-后台查询订单列表-Y
    up_time=1675752735

    params: mobile :  : 购买人手机号
    params: userName :  : 购买人
    params: modelId :  : 车型ID
    params: provinceId :  : 省编码
    params: cityId :  : 市编码
    params: orderId :  : 从新增大定逻辑开始，该字段定义为子订单号
     * * 小订转大定时，前端需要通过这个子订单号小订转大定
    params: mainOrderId :  : 主订单号
    params: orderStatus :  : 订单状态
    params: extOrderStatus :  : 第三方订单状态
    params: dealerCode :  : 经销商ID
    params: orderType :  : 订单类型
    params: channel :  : 渠道id 1 app 2 小程序 3 官网
    params: createStartTime :  : 订单创建开始日期
    params: createEndTime :  : 订单创建结束日期
    params: extNum :  : 三方订单号
    params: current :  : 
    params: size :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : integer :  0.成功 1.失败
    params: msg : string : 
    params: data : object : 
              records : array : 
              total : number : 
              size : number : 
              current : number : 
              orders : array : 
              optimizeCountSql : boolean : 
              searchCount : boolean : 
              countId : string : 
              maxLimit : string : 
              pages : number : 
    """
    _method = "GET"
    _url = "/manageapi/order/mainOrder/pageList"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "mobile": mobile,  # 购买人手机号
        "userName": userName,  # 购买人
        "modelId": modelId,  # 车型ID
        "provinceId": provinceId,  # 省编码
        "cityId": cityId,  # 市编码
        "orderId": orderId,  # 从新增大定逻辑开始，该字段定义为子订单号      * * 小订转大定时，前端需要通过这个子订单号小订转大定
        "mainOrderId": mainOrderId,  # 主订单号
        "orderStatus": orderStatus,  # 订单状态
        "extOrderStatus": extOrderStatus,  # 第三方订单状态
        "dealerCode": dealerCode,  # 经销商ID
        "orderType": orderType,  # 订单类型
        "channel": channel,  # 渠道id 1 app 2 小程序 3 官网
        "createStartTime": createStartTime,  # 订单创建开始日期
        "createEndTime": createEndTime,  # 订单创建结束日期
        "extNum": extNum,  # 三方订单号
        "current": current,
        "size": size,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/manageapi/order/mainOrder/detail")
def manageapi_order_mainorder_detail(orderId=None, headers=None, **kwargs):
    """
    订单管理-大订订单详情-Y
    up_time=1684999454

    params: orderId :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : object : 
              sortItems : null : 
              createStartTime : null : 
              createEndTime : null : 
              userId : string : 
              orderId : string : 
              orderStatus : string : 
              orderStatusName : string : 
              createTime : string : 
              userName : string : 
              mobile : string : 
              linkmanMobile : string : 
              originMobile : string : 
              prePrice : null : 
              totalPrice : string : 
              referencePrice : string : 参考价
              discountRightsList : array : 折扣权益列表
              provinceId : string : 
              provinceName : string : 
              cityId : string : 
              cityName : string : 
              orderType : string : 
              orderTypeName : string : 
              modelId : string : 
              modelSnapshotId : null : 
              existFreeOrder : string : 
              existFreeOrderName : string : 
              goodsTotal : number : 
              orderProcess : array : 
              prePricePosterImageUrl : string : 
              modelName : string : 
              depositPriceContent : string : 
              prePriceContent : null : 
              freePriceContent : string : 
              freePriceAttachText : null : 
              delFlag : string : 
              preStartTime : string : 
              preEndTime : string : 
              preToDepositStartTime : string : 
              preToDepositEndTime : string : 
              depositStartTime : string : 
              depositEndTime : string : 
              payTime : null : 
              refundTime : null : 
              payType : null : 
              channel : string : 
              channelName : string : 
              createShowTime : null : 
              payShowTime : null : 
              refundShowTime : null : 
              refundMemo : null : 
              orderPayInfo : object : 
              orderRefundInfo : object : 订单退款信息
              version : null : 
              referrerCode : null : 
              purchaseType : string : 
              certTypeCode : string : 
              certTypeName : string : 
              certNo : string : 
              enterpriseName : string : 
              enterpriseTaxNo : string : 
              depositPrice : string : 
              payMethod : string : 
              isPreToDepositOrder : string : 
              dealerCode : string : 
              dealerName : string : 
              dealerHotLink : string : 
              wishId : null : 
              userOrderStatus : string : 
              userOrderStatusName : string : 
              extOrderStatus : null : 
              extNum : null : 
              extOrderStatusName : null : 
              subCreateTime : null : 
              configureList : array : 
              mainOrderId : string : 
              deliveryDate : null : 
              ownerBy : null : 
              ownerMobile : null : 
              carModel : object : 
              withinPreToDepositTime : null : 
              chargePointEquity : null : 
              chargePointEquityStr : null : 
              needShowApplyForChargingPile : null : 
              latestPrice : string : 
              associatedOrder : null : 
              assPreOrderId : null : 
              assDepositOrderId : null : 
              showPrice : null : 
              carOwnerInfoVo : object : 
              vin : null : 
              depositOrderPolicyContent : string : 
              chargeRightsInfoList : array : 
              rightsOrderVo : null : 
              chargeRightsName : null : 
              refundStatus : null : 
              refundStatusName : null : 
              orderRefundTaskVo : object : 
              orderRefundBillVo : object : 
              dealerCodeFront : null : 
              dealerCodeQueen : null : 
              changeTime : null : 
              systemCode : null : 
    """
    _method = "GET"
    _url = "/manageapi/order/mainOrder/detail"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "orderId": orderId,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a.asserts.content.asserts_content_commonquestion import AssertsContentCommonquestion
from service.app_a.apis.content import apis_content_commonquestion


class FunsContentCommonquestion(AssertsContentCommonquestion):
    @allure.step(title="常见问题-上下架-Y")
    def content_commonquestion_updatestatus(self, status="$None$", essayId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/commonquestion/updateStatus
                params: essayId :  : 主键id
                params: status : string : 上架2 下架3
                params: headers : 请求头
        """
        status = self.get_value_choice(status, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        essayId = self.get_value_choice(essayId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_commonquestion.content_commonquestion_updatestatus(**_kwargs)

        self.assert_content_commonquestion_updatestatus(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="常见问题-修改-Y")
    def content_commonquestion_update(self, title="$None$", content="$None$", essayId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/commonquestion/update
                params: essayId :  : 主键id
                params: title : string : 标题
                params: content : string : 内容
                params: headers : 请求头
        """
        title = self.get_value_choice(title, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        content = self.get_value_choice(content, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        essayId = self.get_value_choice(essayId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_commonquestion.content_commonquestion_update(**_kwargs)

        self.assert_content_commonquestion_update(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="常见问题-修改权重-Y")
    def content_commonquestion_updaterank(self, rank="$None$", essayId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/commonquestion/updateRank
                params: essayId :  : 主键id
                params: rank : string : 权重
                params: headers : 请求头
        """
        rank = self.get_value_choice(rank, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        essayId = self.get_value_choice(essayId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_commonquestion.content_commonquestion_updaterank(**_kwargs)

        self.assert_content_commonquestion_updaterank(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="常见问题-删除-Y")
    def content_commonquestion_delete(self, essayId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/commonquestion/delete
                params: essayId :  : 主键id
                params: headers : 请求头
        """
        essayId = self.get_value_choice(essayId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_commonquestion.content_commonquestion_delete(**_kwargs)

        self.assert_content_commonquestion_delete(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="常见问题-后台列表-Y")
    def content_commonquestion_list(self, size=10, current=1, _assert=True,  **kwargs):
        """
            url=/content/commonquestion/list
                params: current :  : 当前页数
                params: size :  : 每页个数
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_commonquestion.content_commonquestion_list(**_kwargs)

        self.assert_content_commonquestion_list(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="常见问题-已发布列表-Y")
    def content_commonquestion_publishlist(self, size=10, current=1, _assert=True,  **kwargs):
        """
            url=/content/commonquestion/publishList
                params: current :  : 当前页数
                params: size :  : 每页数量
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_commonquestion.content_commonquestion_publishlist(**_kwargs)

        self.assert_content_commonquestion_publishlist(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="常见问题-新增-Y")
    def content_commonquestion_add(self, title="$None$", content="$None$", essayId="$None$", _assert=True, _all_is_None=False,  **kwargs):
        """
            url=/content/commonquestion/add
                params: essayId :  : 主键id
                params: title : string : 标题
                params: content : string : 内容
                params: headers : 请求头
        """
        title = self.get_value_choice(title, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        content = self.get_value_choice(content, list_or_dict=None, key=None, _all_is_None=_all_is_None)
        essayId = self.get_value_choice(essayId, list_or_dict=None, key=None, _all_is_None=_all_is_None)

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_commonquestion.content_commonquestion_add(**_kwargs)

        self.assert_content_commonquestion_add(_assert, **_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="常见问题-生成id-Y")
    def content_commonquestion_createid(self, _assert=True,  **kwargs):
        """
            url=/content/commonquestion/createId
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_commonquestion.content_commonquestion_createid(**_kwargs)

        self.assert_content_commonquestion_createid(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)


    @allure.step(title="常见问题-详情-Y")
    def content_commonquestion_info(self, essayId="$None$", _assert=True,  **kwargs):
        """
            url=/content/commonquestion/info
                params: essayId :  : 主键id
                params: headers : 请求头
        """
        essayId = self.get_list_choice(essayId, list_or_dict=None, key="essayId")

        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_commonquestion.content_commonquestion_info(**_kwargs)

        self.assert_content_commonquestion_info(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/campManager/page")
def content_campmanager_page(sortBody=None, name=None, id=None, sortord=None, createBy=None, status=None, headers=None, **kwargs):
    """
    营地服务列表 - 分页查询
    up_time=1681969132

    params: id :  : 
    params: name :  : 
    params: status :  : 
    params: createBy :  : 
    params: sortBody :  : 
    params: sortord :  : ASC/DESC/asc/desc
    params: headers : 请求头
    ====================返回======================
    params: code : number : 接口状态
    params: msg : string : 提示信息
    params: data : object : 
              id : string : 营地服务id
              name : string : 营地名称
              content : string : 营地简介
              campDetail : string : 营地详情
              url : string : 营地图片
              status : number : 1已上架 0已下架
              commentCnt : number : 评论量
              thumbsCnt : number : 点赞量
              createBy : string : 创建人
              updateTime : string : 上架时间
    """
    _method = "GET"
    _url = "/content/campManager/page"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "id": id,
        "name": name,
        "status": status,
        "createBy": createBy,
        "sortBody": sortBody,
        "sortord": sortord,  # ASC/DESC/asc/desc
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/campManager/soldOut")
def content_campmanager_soldout(id=None, campId=None, headers=None, **kwargs):
    """
    营地列表 - 下架/批量下架
    up_time=1681959868

    params: id :  : 
    params: campId : array : 营地服务ID
              type : string : None
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : string : 操作成功
    """
    _method = "PUT"
    _url = "/content/campManager/soldOut"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "id": id,
        "campId": campId,  # 营地服务ID
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/campManager/insertCampID")
def content_campmanager_insertcampid( headers=None, **kwargs):
    """
    新增营地 - 新增营地ID带出
    up_time=1681960296

    params: headers : 请求头
    ====================返回======================
    params: code : string : 
    params: msg : string : 
    params: data : string : 营地服务ID
    """
    _method = "GET"
    _url = "/content/campManager/insertCampID"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/campManager/insert")
def content_campmanager_insert(city=None, campDetail=None, name=None, url=None, province=None, discountExpEndTime=None, discountExpBeginTime=None, id=None, campTradeTime=None, county=None, ownerDiscount=None, content=None, address=None, headers=None, **kwargs):
    """
    新增营地
    up_time=1681967827

    params: id : text : 营地服务ID
    params: name : text : 营地名称
    params: content : text : 营地简介
    params: url : text : 营地图片
    params: campDetail : text : 营地详情
    params: ownerDiscount : text : 车主优惠
    params: campTradeTime : text : 营地营业时间
    params: discountExpBeginTime : text : 车主优惠有效期 - 开始时间
    params: discountExpEndTime : text : 车主优惠有效期 - 结束时间
    params: province : text : 省
    params: city : text : 市
    params: county : text : 区/县
    params: address : text : 详细地址
    params: headers : 请求头
    ====================返回======================
    params: code : number : 
    params: msg : string : 
    params: data : string : 新增成功
    """
    _method = "POST"
    _url = "/content/campManager/insert"

    _headers = {
        "Content-Type": "application/x-www-form-urlencoded",
    }
    _headers.update({"headers": headers})

    _data = {
        "id": id,  # 营地服务ID
        "name": name,  # 营地名称
        "content": content,  # 营地简介
        "url": url,  # 营地图片
        "campDetail": campDetail,  # 营地详情
        "ownerDiscount": ownerDiscount,  # 车主优惠
        "campTradeTime": campTradeTime,  # 营地营业时间
        "discountExpBeginTime": discountExpBeginTime,  # 车主优惠有效期 - 开始时间
        "discountExpEndTime": discountExpEndTime,  # 车主优惠有效期 - 结束时间
        "province": province,  # 省
        "city": city,  # 市
        "county": county,  # 区/县
        "address": address,  # 详细地址
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/campManager/detail/")
def content_campmanager_detail_(id=None, headers=None, **kwargs):
    """
    营地列表 - 营地详情
    up_time=1681969814

    params: id :  : 营地服务ID
    params: headers : 请求头
    ====================返回======================
    params: code : string : 
    params: msg : string : 
    params: data : object : 
              id : string : 营地服务id
              name : string : 营地名称
              content : string : 营地简介
              campDetail : string : 营地详情
              url : string : 营地图片
              ownerDiscount : string : 车主优惠
              campTradeTime : string : 营地营业时间
              discountExpBeginTime : string : 车主优惠有效期 - 开始时间
              discountExpEndTime : string : 车主优惠有效期 - 结束时间
              province : string : 省
              city : string : 市
              county : string : 区/县
              address : string : 详细地址
    """
    _method = "GET"
    _url = "/content/campManager/detail/{id}"
    _url = get_url(_url, locals())

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
    }

    _params = {
        "id": id,  # 营地服务ID
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/content/campManager/update")
def content_campmanager_update(phone=None, discountExpEndTime=None, discountExpBeginTime=None, ownerDiscount=None, areaCode=None, headers=None, **kwargs):
    """
    编辑营地
    up_time=1681969876

    params: ownerDiscount : text : 车主优惠
    params: discountExpBeginTime : text : 车主优惠有效期 - 开始时间
    params: discountExpEndTime : text : 车主优惠有效期 - 结束时间
    params: areaCode : text : 区号
    params: phone : text : 手机号
    params: headers : 请求头
    ====================返回======================
    params: code : string : 
    params: msg : string : 
    params: data : string : 编辑成功
    """
    _method = "POST"
    _url = "/content/campManager/update"

    _headers = {
        "Content-Type": "application/x-www-form-urlencoded",
    }
    _headers.update({"headers": headers})

    _data = {
        "ownerDiscount": ownerDiscount,  # 车主优惠
        "discountExpBeginTime": discountExpBeginTime,  # 车主优惠有效期 - 开始时间
        "discountExpEndTime": discountExpEndTime,  # 车主优惠有效期 - 结束时间
        "areaCode": areaCode,  # 区号
        "phone": phone,  # 手机号
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)





import allure

from service.app_a import unit_request
from service.app_a.sqls.manageapi.order.sqls_manageapi_order_mainorder import SqlsManageapiOrderMainorder


class AssertsManageapiOrderMainorder(SqlsManageapiOrderMainorder):
    @allure.step(title="接口返回结果校验")
    def assert_manageapi_order_mainorder_pagelist(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_manageapi_order_mainorder_pagelist(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["createEndTime", "orderStatus", "extOrderStatus", "mainOrderId", "userName", "extNum", "channel", "dealerCode", "cityId", "mobile", "provinceId", "orderId", "createStartTime", "orderType", "modelId"])
        # assert flag, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_manageapi_order_mainorder_detail(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_manageapi_order_mainorder_detail(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["orderId"])
        # assert flag, "数据比较不一致"




import allure

from service.app_a.asserts.content.asserts_content_hotcity import AssertsContentHotcity
from service.app_a.apis.content import apis_content_hotcity


class FunsContentHotcity(AssertsContentHotcity):
    @allure.step(title="热门城市-Y")
    def content_hotcity_list(self, _assert=True,  **kwargs):
        """
            url=/content/hotcity/list
                params: headers : 请求头
        """
        _kwargs = self.get_kwargs(locals())
        self.res = apis_content_hotcity.content_hotcity_list(**_kwargs)

        self.assert_content_hotcity_list(_assert, **_kwargs)
        self.set_output_value(_kwargs)
        self.set_value(_kwargs)





import allure

from service.app_a import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/content/adv/")
def content_adv_(advId=None, headers=None, **kwargs):
    """
    点位内容-通过id删除点位内容-Y
    up_time=1675674580

    params: advId :  : 
    params: headers : 请求头
    ====================返回======================
    params: code : integer : 
    params: msg : string : 
    params: data : boolean : 
    """
    _method = "DELETE"
    _url = "/content/adv/{advId}"
    _url = get_url(_url, locals())

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "advId": advId,
    }

    _params = {
        "advId": advId,
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


